@@ -28,7 +28,12 @@ SCIBERT_URL_DICT = {
 
 lang2model = defaultdict(lambda: "bert-base-multilingual-cased")
 lang2model.update(
-    {"en": "roberta-large", "zh": "bert-base-chinese", "en-sci": "scibert-scivocab-uncased",}
+    {
+        "en": "roberta-large",
+        "zh": "bert-base-chinese",
+        "tr": "dbmdz/bert-base-turkish-cased",
+        "en-sci": "allenai/scibert_scivocab_uncased",
+    }
 )
 
 
@@ -47,10 +52,13 @@ model2layers = {
     "xlnet-large-cased": 7,  # 0.6598800720297179
     "xlm-mlm-en-2048": 6,  # 0.651262570131464
     "xlm-mlm-100-1280": 10,  # 0.6475166424401905
-    "scibert-scivocab-uncased": 8,  # 0.6590354319927313
-    "scibert-scivocab-cased": 9,  # 0.6536375053937445
-    "scibert-basevocab-uncased": 9,  # 0.6748944832703548
-    "scibert-basevocab-cased": 9,  # 0.6524624150542374
+    # "scibert-scivocab-uncased": 8,  # 0.6590354319927313
+    # "scibert-scivocab-cased": 9,  # 0.6536375053937445
+    # "scibert-basevocab-uncased": 9,  # 0.6748944832703548
+    # "scibert-basevocab-cased": 9,  # 0.6524624150542374
+    'allenai/scibert_scivocab_uncased': 8, # 0.6590354393124127
+    'allenai/scibert_scivocab_cased': 9, # 0.6536374902465466
+    'nfliu/scibert_basevocab_uncased': 9, # 0.6748945076082333
     "distilroberta-base": 5,  # 0.6797558139322964
     "distilbert-base-uncased": 5,  # 0.6756659152782033
     "distilbert-base-uncased-distilled-squad": 4,  # 0.6718318036382493
@@ -155,6 +163,16 @@ model2layers = {
     'google/bigbird-roberta-base': 10, # 0.6695606423502717
     'google/bigbird-roberta-large': 14, # 0.6755874042374509
     'google/bigbird-base-trivia-itc': 8, # 0.6930725491629892
+    'princeton-nlp/unsup-simcse-bert-base-uncased': 10, # 0.6703066531921142
+    'princeton-nlp/unsup-simcse-bert-large-uncased': 18, # 0.6958302800755326
+    'princeton-nlp/unsup-simcse-roberta-base': 8, # 0.6436615893535319
+    'princeton-nlp/unsup-simcse-roberta-large': 13, # 0.6812864385585965
+    'princeton-nlp/sup-simcse-bert-base-uncased': 10, # 0.7068074935240984
+    'princeton-nlp/sup-simcse-bert-large-uncased': 18, # 0.7111049471332378
+    'princeton-nlp/sup-simcse-roberta-base': 10, # 0.7253123806661946
+    'princeton-nlp/sup-simcse-roberta-large': 16, # 0.7497820277237173
+    'dbmdz/bert-base-turkish-cased': 10, # WMT18 seg en-tr 0.5522827687776142
+    'dbmdz/distilbert-base-turkish-cased': 4, # WMT18 seg en-tr 0.4742268041237113
 }
 
 
@@ -261,13 +279,14 @@ def get_model(model_type, num_layers, all_layers=None):
     return model
 
 
-def get_tokenizer(model_type):
+def get_tokenizer(model_type, use_fast=False):
     if model_type.startswith("scibert"):
         model_type = cache_scibert(model_type)
 
     if LooseVersion(trans_version) >= LooseVersion("4.0.0"):
-        tokenizer = AutoTokenizer.from_pretrained(model_type, use_fast=False)
+        tokenizer = AutoTokenizer.from_pretrained(model_type, use_fast=use_fast)
     else:
+        assert not use_fast, "Fast tokenizer is not available for version < 4.0.0"
         tokenizer = AutoTokenizer.from_pretrained(model_type)
 
     return tokenizer
@@ -451,12 +470,14 @@ def greedy_cos_idf(ref_embedding, ref_masks, ref_idf, hyp_embedding, hyp_masks,
 
     if torch.any(hyp_zero_mask):
         print(
-            "Warning: Empty candidate sentence detected; setting precision to be 0.", file=sys.stderr,
+            "Warning: Empty candidate sentence detected; setting raw BERTscores to 0.", file=sys.stderr,
         )
         P = P.masked_fill(hyp_zero_mask, 0.0)
+        R = R.masked_fill(hyp_zero_mask, 0.0)
 
     if torch.any(ref_zero_mask):
-        print("Warning: Empty reference sentence detected; setting recall to be 0.", file=sys.stderr)
+        print("Warning: Empty reference sentence detected; setting raw BERTScores to 0.", file=sys.stderr)
+        P = P.masked_fill(ref_zero_mask, 0.0)
         R = R.masked_fill(ref_zero_mask, 0.0)
 
     F = F.masked_fill(torch.isnan(F), 0.0)
@@ -544,7 +565,7 @@ def bert_cos_score_idf(
     return preds
 
 
-def get_hash(model, num_layers, idf, rescale_with_baseline, use_custom_baseline):
+def get_hash(model, num_layers, idf, rescale_with_baseline, use_custom_baseline, use_fast_tokenizer):
     msg = "{}_L{}{}_version={}(hug_trans={})".format(
         model, num_layers, "_idf" if idf else "_no-idf", __version__, trans_version
     )
@@ -553,6 +574,8 @@ def get_hash(model, num_layers, idf, rescale_with_baseline, use_custom_baseline)
             msg += "-custom-rescaled"
         else:
             msg += "-rescaled"
+    if use_fast_tokenizer:
+        msg += "_fast-tokenizer"
     return msg
 
 
